@@ -7,7 +7,7 @@ use warnings;
 
 =head1 NAME
 
-Sys::Binmode - A fix for Perl’s system call encoding bug.
+Sys::Binmode - A fix for Perl’s system call character encoding
 
 =begin html
 
@@ -19,20 +19,21 @@ Sys::Binmode - A fix for Perl’s system call encoding bug.
 
     use Sys::Binmode;
 
-    my $foo = "é";
+    my $foo = "\xff";
     $foo .= "\x{100}";
     chop $foo;
 
-    # Prints “é”:
+    # Prints a single octet (0xFF) and a newline:
     print $foo, $/;
 
-    # In Perl 5.32 this may print mojibake,
-    # but with Sys::Binmode it always prints “é”:
+    # In Perl 5.32 this may print the same single octet, or it may
+    # print UTF-8-encoded U+00FF. With Sys::Binmode, though, it always
+    # gives the single octet, just like print:
     exec 'echo', $foo;
 
 =head1 DESCRIPTION
 
-tl;dr: You I<probably> should use this module in B<all> new code.
+tl;dr: Use this module in B<all> new code.
 
 =head1 BACKGROUND
 
@@ -56,11 +57,15 @@ use the string correctly.
 Alas, that differentiation doesn’t always happen. Thus, Perl can
 output a string that stores one or more 128-255 code points
 differently depending on whether Perl has “optimized” that string or not.
-Remember, though, that Perl applications I<should> I<not> I<care> about
+
+Remember, though: Perl applications I<should> I<not> I<care> about
 Perl’s string storage internals. (This is why, for example, the L<bytes>
-pragma is discouraged.) But without that knowledge, the application can’t
-know what it actually says to the outside world! Thus we have unpredictable
-behaviour, which is categorically bad.
+pragma is discouraged.) The catch, though, is that without that knowledge,
+B<the> B<application> B<can’t> B<know> B<what> B<it> B<actually> B<says>
+B<to> B<the> B<outside> B<world!>
+
+Thus, applications must either monitor Perl’s string-storage internals
+or accept unpredictable behaviour, both of which are categorically bad.
 
 =head1 HOW THIS MODULE (PARTLY) FIXES THE PROBLEM
 
@@ -86,19 +91,21 @@ The fix is to apply an explicit UTF-8 encode prior to the system call
 that throws the error. This is what we should do I<anyway>;
 Sys::Binmode just enforces that better.
 
-=head2 Windows (et alia)
+=head2 Non-POSIX Operating Systems (e.g., Windows)
 
-NTFS, Windows’s primary filesystem, expects filenames to be encoded in
-little-endian UTF-16. To create a file named C<épée>, then, on NTFS
-you have to do something like:
+In a POSIX operating system, an application’s communication with the
+OS happens entirely through byte strings. Thus, treating all
+OS-destined strings as byte strings is good and natural.
 
-    my $windows_filename = Encode::Simple::encode( 'UTF-16LE', $filename );
+In Windows, though, things are weirder. For example, Windows
+exposes multiple APIs for creating a directory, and the one Perl uses (as of
+5.32, anyway) only accepts code points 0-255. In this context Sys::Binmode
+doesn’t I<break> anything, but it does reinforce one of Perl’s unfortunate
+limitations on Windows.
 
-… where C<$filename> is a character (i.e., decoded) string.
-
-Other OSes and filesystems may have their own quirks; regardless, this
-module gives you a saner point of departure to address those
-than Perl’s default behaviour provides.
+Sys::Binmode is a good idea anywhere that Perl sends byte strings to the OS.
+As far as I know, that’s everywhere that Perl runs. If that’s not true,
+please file a bug.
 
 =head1 WHERE ELSE THIS PROBLEM CAN APPEAR
 
@@ -128,6 +135,8 @@ C<no Sys::Binmode>, thus:
     system 'echo', $foo;        # predictable/sane/happy
 
     {
+
+        # You should probably explain here why you’re doing this.
         no Sys::Binmode;
 
         system 'echo', $foo;    # nasal demons
@@ -164,7 +173,7 @@ If you’d like them, ask.
 
 =item * Ideally this behaviour should be in Perl’s core distribution.
 
-=item * Even more ideally, this behaviour should be Perl’s I<default>.
+=item * Even more ideally, Perl should adopt this behaviour as I<default>.
 Maybe someday!
 
 =back
@@ -173,13 +182,11 @@ Maybe someday!
 
 #----------------------------------------------------------------------
 
-our $VERSION = '0.01_03';
+our $VERSION = '0.02_01';
 
 require XSLoader;
 XSLoader::load(__PACKAGE__, $VERSION);
 
-use constant _HINT_KEY => __PACKAGE__ . '/enabled';
-
 sub import {
     $^H{ _HINT_KEY() } = 1;
 
@@ -194,7 +201,8 @@ sub unimport {
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to Leon Timmermans (LEONT) for some debugging help.
+Thanks to Leon Timmermans (LEONT) and Paul Evans (PEVANS) for some
+debugging and design help.
 
 =head1 LICENSE & COPYRIGHT
 
